@@ -61,3 +61,31 @@ class Database(metaclass=DatabaseMeta):
             json.dump(self.data, file, **additional)
 
         logger.debug('Saved data into file %s', self.path)
+
+
+class DatabaseFolder:
+
+    def __init__(self,
+                 folder: str,
+                 default_factory: typing.Callable = lambda _: None,
+                 save_at_exit: bool = True,
+                 ):
+        self.folder = folder
+        self._default_factory = default_factory
+        self._save_at_exit = save_at_exit
+
+    def _name_to_filepath(self, name: str) -> str:
+        return os.path.join(self.folder, f'{name}.json')
+
+    def database(self, name: str):
+        return Database(
+            self._name_to_filepath(name),
+            default=self._default_factory(name),
+            save_at_exit=self._save_at_exit,
+        )
+
+    def __getitem__(self, name: str):
+        return self.database(name).data
+
+    def __setitem__(self, name: str, value):
+        self.database(name).data = value
